searchData={"content_type":"text/markdown","items":[{"doc":"This check has a base priority of `higher` and works with any version of Elixir.","ref":"Credo.Checks.Readability.ComplexElseClauses.html","title":"Credo.Checks.Readability.ComplexElseClauses","type":"module"},{"doc":"Problem: This code smell refers to with statements that flatten all its error clauses into a single complex else block.\n  This situation is harmful to the code readability and maintainability\n  because difficult to know from which clause the error value came.\n\n  Example: An example of this code smell, as shown below, is a function open_decoded_file/1 that read a base 64 encoded string content from a file and returns a decoded binary string. This function uses a with statement that needs to handle two possible errors, all of which are concentrated in a single complex else block.\n  The code in this example ...\n\n      def open_decoded_file(path) do\n        with {:ok, encoded}   :badfile\n          :error -> :badencoding\n        end\n      end\n\n  ... should be refactored to look like this:\n\n      def open_decoded_file(path) do\n        with {:ok, encoded}   {:ok, contents}\n          {:error, _} -> :badfile\n        end\n      end\n\n      defp base_decode64(contents) do\n        case Base.decode64(contents) do\n          {:ok, contents} -> {:ok, contents}\n          :error -> :badencoding\n        end\n      end\n\n  As shown above, in this situation,\n  instead of concentrating all error handlings within a single complex else block,\n  it is better to normalize the return types in specific private functions. In this way,\n  due to its organization, the code will be cleaner and more readable.","ref":"Credo.Checks.Readability.ComplexElseClauses.html#module-explanation","title":"Explanation - Credo.Checks.Readability.ComplexElseClauses","type":"module"},{"doc":"*There are no specific parameters for this check.*","ref":"Credo.Checks.Readability.ComplexElseClauses.html#module-check-specific-parameters","title":"Check-Specific Parameters - Credo.Checks.Readability.ComplexElseClauses","type":"module"},{"doc":"Like with all checks, [general params](check_params.html) can be applied.\n\nParameters can be configured via the [`.credo.exs` config file](config_file.html).","ref":"Credo.Checks.Readability.ComplexElseClauses.html#module-general-parameters","title":"General Parameters - Credo.Checks.Readability.ComplexElseClauses","type":"module"},{"doc":"","ref":"Credo.Checks.Readability.ComplexElseClauses.html#issue_for/2","title":"Credo.Checks.Readability.ComplexElseClauses.issue_for/2","type":"function"},{"doc":"","ref":"Smell.html","title":"Smell","type":"module"},{"doc":"","ref":"Smell.html#init/1","title":"Smell.init/1","type":"function"}]}